# Mailosaur Python Client Library

[Mailosaur](https://mailosaur.com) allows you to automate tests involving email. Allowing you to perform end-to-end automated and functional email testing.

[![Build Status](https://travis-ci.org/mailosaur/mailosaur-python.svg?branch=master)](https://travis-ci.org/mailosaur/mailosaur-python)

## Installation

```
pip install --upgrade mailosaur
```

## Documentation and usage examples

[Mailosaur's documentation](https://mailosaur.com/docs) includes all the information and usage examples you'll need.

## Running tests

Once you've cloned this repository locally, you can simply run:

```
pip install -r requirements.txt

export MAILOSAUR_API_KEY=your_api_key
export MAILOSAUR_SERVER=server_id

nosetests
```

## Contacting us

You can get us at [support@mailosaur.com](mailto:support@mailosaur.com)
